/*
 * Copyright (c) 2016 - 2017 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

#ifndef __BADGE_SETTING_SERVICE_H__
#define __BADGE_SETTING_SERVICE_H__

#include <stdbool.h>
#include <sys/types.h>
#include "badge_error.h"
#include "badge_setting.h"

#ifdef __cplusplus
extern "C" {
#endif /*  __cplusplus */

/**
 * @file badge_setting_service.h
 * @brief This file contains the badge APIs.
 */

/**
 * @addtogroup BADGE_MODULE
 * @{
 */

int badge_db_get_setting_by_appid(const char *appid, badge_setting_h *setting, uid_t uid);
int badge_db_get_allow_to_display_by_appid(char *appid, int *allow_to_display, uid_t uid);
int badge_setting_insert_package_for_uid(const char *pkgname, uid_t uid);
int badge_setting_delete_package_for_uid(const char *pkgname, uid_t uid);
int badge_setting_refresh_setting_table(uid_t uid);
int badge_db_update_setting(char *pkgname, char *appid, int allow_to_display, uid_t uid);

/**
 * @}
 */

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* __BADGE_SETTING_SERVICE_H__ */

